/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.codegen.generated;

import com.intellij.testFramework.TestDataPath;
import org.jetbrains.kotlin.test.InnerTestClasses;
import org.jetbrains.kotlin.test.JUnit3RunnerWithInners;
import org.jetbrains.kotlin.test.JetTestUtils;
import org.jetbrains.kotlin.test.TestMetadata;
import org.junit.runner.RunWith;

import java.io.File;
import java.util.regex.Pattern;

/** This class is generated by {@link org.jetbrains.kotlin.generators.tests.TestsPackage}. DO NOT MODIFY MANUALLY */
@SuppressWarnings("all")
@TestMetadata("compiler/testData/codegen/boxAgainstJava")
@TestDataPath("$PROJECT_ROOT")
@InnerTestClasses({
        BlackBoxAgainstJavaCodegenTestGenerated.Annotations.class,
        BlackBoxAgainstJavaCodegenTestGenerated.CallableReference.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Constructor.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Delegation.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Enum.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Functions.class,
        BlackBoxAgainstJavaCodegenTestGenerated.InnerClass.class,
        BlackBoxAgainstJavaCodegenTestGenerated.NotNullAssertions.class,
        BlackBoxAgainstJavaCodegenTestGenerated.PlatformTypes.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Property.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Reflection.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Sam.class,
        BlackBoxAgainstJavaCodegenTestGenerated.StaticFun.class,
        BlackBoxAgainstJavaCodegenTestGenerated.Visibility.class,
})
@RunWith(JUnit3RunnerWithInners.class)
public class BlackBoxAgainstJavaCodegenTestGenerated extends AbstractBlackBoxCodegenTest {
    public void testAllFilesPresentInBoxAgainstJava() throws Exception {
        JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava"), Pattern.compile("^(.+)\\.kt$"), true);
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/annotations")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Annotations extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInAnnotations() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/annotations"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("javaAnnotationCall.kt")
        public void testJavaAnnotationCall() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/annotations/javaAnnotationCall.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("javaAnnotationDefault.kt")
        public void testJavaAnnotationDefault() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/annotations/javaAnnotationDefault.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("javaNegativePropertyAsAnnotationParameter.kt")
        public void testJavaNegativePropertyAsAnnotationParameter() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/annotations/javaNegativePropertyAsAnnotationParameter.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("javaPropertyAsAnnotationParameter.kt")
        public void testJavaPropertyAsAnnotationParameter() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/annotations/javaPropertyAsAnnotationParameter.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("javaPropertyWithIntInitializer.kt")
        public void testJavaPropertyWithIntInitializer() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/annotations/javaPropertyWithIntInitializer.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("retentionInJava.kt")
        public void testRetentionInJava() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/annotations/retentionInJava.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/callableReference")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class CallableReference extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInCallableReference() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/callableReference"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("constructor.kt")
        public void testConstructor() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/callableReference/constructor.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("publicFinalField.kt")
        public void testPublicFinalField() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/callableReference/publicFinalField.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("publicMutableField.kt")
        public void testPublicMutableField() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/callableReference/publicMutableField.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("staticMethod.kt")
        public void testStaticMethod() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/callableReference/staticMethod.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/constructor")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Constructor extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInConstructor() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/constructor"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("genericConstructor.kt")
        public void testGenericConstructor() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/constructor/genericConstructor.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("secondaryConstructor.kt")
        public void testSecondaryConstructor() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/constructor/secondaryConstructor.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/delegation")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Delegation extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInDelegation() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/delegation"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("delegationAndInheritanceFromJava.kt")
        public void testDelegationAndInheritanceFromJava() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/delegation/delegationAndInheritanceFromJava.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/enum")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Enum extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInEnum() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/enum"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("simpleJavaEnum.kt")
        public void testSimpleJavaEnum() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/enum/simpleJavaEnum.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("simpleJavaEnumWithFunction.kt")
        public void testSimpleJavaEnumWithFunction() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/enum/simpleJavaEnumWithFunction.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("simpleJavaEnumWithStaticImport.kt")
        public void testSimpleJavaEnumWithStaticImport() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/enum/simpleJavaEnumWithStaticImport.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("simpleJavaInnerEnum.kt")
        public void testSimpleJavaInnerEnum() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/enum/simpleJavaInnerEnum.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("staticField.kt")
        public void testStaticField() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/enum/staticField.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("staticMethod.kt")
        public void testStaticMethod() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/enum/staticMethod.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/functions")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Functions extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInFunctions() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/functions"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("constructor.kt")
        public void testConstructor() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/functions/constructor.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("max.kt")
        public void testMax() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/functions/max.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("referencesStaticInnerClassMethod.kt")
        public void testReferencesStaticInnerClassMethod() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/functions/referencesStaticInnerClassMethod.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("referencesStaticInnerClassMethodL2.kt")
        public void testReferencesStaticInnerClassMethodL2() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/functions/referencesStaticInnerClassMethodL2.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("unrelatedUpperBounds.kt")
        public void testUnrelatedUpperBounds() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/functions/unrelatedUpperBounds.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/innerClass")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class InnerClass extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInInnerClass() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/innerClass"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("kt3532.kt")
        public void testKt3532() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/innerClass/kt3532.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("kt3812.kt")
        public void testKt3812() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/innerClass/kt3812.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("kt4036.kt")
        public void testKt4036() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/innerClass/kt4036.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/notNullAssertions")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class NotNullAssertions extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInNotNullAssertions() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/notNullAssertions"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("Delegation.kt")
        public void testDelegation() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/notNullAssertions/Delegation.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/platformTypes")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class PlatformTypes extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInPlatformTypes() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/platformTypes"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("GenericUnit.kt")
        public void testGenericUnit() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/platformTypes/GenericUnit.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/property")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Property extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInProperty() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/property"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("fieldAccessFromExtensionInTraitImpl.kt")
        public void testFieldAccessFromExtensionInTraitImpl() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/property/fieldAccessFromExtensionInTraitImpl.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("fieldAccessViaSubclass.kt")
        public void testFieldAccessViaSubclass() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/property/fieldAccessViaSubclass.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("referenceToJavaFieldViaBridge.kt")
        public void testReferenceToJavaFieldViaBridge() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/property/referenceToJavaFieldViaBridge.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/reflection")
    @TestDataPath("$PROJECT_ROOT")
    @InnerTestClasses({
            Reflection.ClassLiterals.class,
            Reflection.Mapping.class,
            Reflection.Properties.class,
    })
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Reflection extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInReflection() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/reflection"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/reflection/classLiterals")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class ClassLiterals extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInClassLiterals() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/reflection/classLiterals"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("javaClassLiteral.kt")
            public void testJavaClassLiteral() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/reflection/classLiterals/javaClassLiteral.kt");
                doTestAgainstJava(fileName);
            }
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/reflection/mapping")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Mapping extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInMapping() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/reflection/mapping"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("jClass2kClass.kt")
            public void testJClass2kClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/reflection/mapping/jClass2kClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("javaFields.kt")
            public void testJavaFields() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/reflection/mapping/javaFields.kt");
                doTestAgainstJava(fileName);
            }
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/reflection/properties")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Properties extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInProperties() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/reflection/properties"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("equalsHashCodeToString.kt")
            public void testEqualsHashCodeToString() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/reflection/properties/equalsHashCodeToString.kt");
                doTestAgainstJava(fileName);
            }
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/sam")
    @TestDataPath("$PROJECT_ROOT")
    @InnerTestClasses({
            Sam.Adapters.class,
    })
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Sam extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInSam() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/sam"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("differentFqNames.kt")
        public void testDifferentFqNames() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/differentFqNames.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("samConstructorGenericSignature.kt")
        public void testSamConstructorGenericSignature() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/samConstructorGenericSignature.kt");
            doTestAgainstJava(fileName);
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters")
        @TestDataPath("$PROJECT_ROOT")
        @InnerTestClasses({
                Adapters.Operators.class,
        })
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Adapters extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInAdapters() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/sam/adapters"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("bridgesForOverridden.kt")
            public void testBridgesForOverridden() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/bridgesForOverridden.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("bridgesForOverriddenComplex.kt")
            public void testBridgesForOverriddenComplex() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/bridgesForOverriddenComplex.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("callAbstractAdapter.kt")
            public void testCallAbstractAdapter() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/callAbstractAdapter.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("comparator.kt")
            public void testComparator() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/comparator.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("constructor.kt")
            public void testConstructor() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/constructor.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("fileFilter.kt")
            public void testFileFilter() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/fileFilter.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("genericSignature.kt")
            public void testGenericSignature() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/genericSignature.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("implementAdapter.kt")
            public void testImplementAdapter() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/implementAdapter.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("inheritedInKotlin.kt")
            public void testInheritedInKotlin() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/inheritedInKotlin.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("inheritedOverriddenAdapter.kt")
            public void testInheritedOverriddenAdapter() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/inheritedOverriddenAdapter.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("inheritedSimple.kt")
            public void testInheritedSimple() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/inheritedSimple.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("nonLiteralAndLiteralRunnable.kt")
            public void testNonLiteralAndLiteralRunnable() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/nonLiteralAndLiteralRunnable.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("nonLiteralComparator.kt")
            public void testNonLiteralComparator() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/nonLiteralComparator.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("nonLiteralInConstructor.kt")
            public void testNonLiteralInConstructor() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/nonLiteralInConstructor.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("nonLiteralNull.kt")
            public void testNonLiteralNull() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/nonLiteralNull.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("nonLiteralRunnable.kt")
            public void testNonLiteralRunnable() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/nonLiteralRunnable.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("severalSamParameters.kt")
            public void testSeveralSamParameters() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/severalSamParameters.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("simplest.kt")
            public void testSimplest() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/simplest.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("superconstructor.kt")
            public void testSuperconstructor() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/superconstructor.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("typeParameterOfClass.kt")
            public void testTypeParameterOfClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/typeParameterOfClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("typeParameterOfMethod.kt")
            public void testTypeParameterOfMethod() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/typeParameterOfMethod.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("typeParameterOfOuterClass.kt")
            public void testTypeParameterOfOuterClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/typeParameterOfOuterClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Operators extends AbstractBlackBoxCodegenTest {
                public void testAllFilesPresentInOperators() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("augmentedAssignmentAndSquareBrackets.kt")
                public void testAugmentedAssignmentAndSquareBrackets() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/augmentedAssignmentAndSquareBrackets.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("augmentedAssignmentPure.kt")
                public void testAugmentedAssignmentPure() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/augmentedAssignmentPure.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("augmentedAssignmentViaSimpleBinary.kt")
                public void testAugmentedAssignmentViaSimpleBinary() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/augmentedAssignmentViaSimpleBinary.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("binary.kt")
                public void testBinary() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/binary.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("compareTo.kt")
                public void testCompareTo() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/compareTo.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("contains.kt")
                public void testContains() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/contains.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("get.kt")
                public void testGet() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/get.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("infixCall.kt")
                public void testInfixCall() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/infixCall.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("invoke.kt")
                public void testInvoke() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/invoke.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("multiGetSet.kt")
                public void testMultiGetSet() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/multiGetSet.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("multiInvoke.kt")
                public void testMultiInvoke() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/multiInvoke.kt");
                    doTestAgainstJava(fileName);
                }

                @TestMetadata("set.kt")
                public void testSet() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/sam/adapters/operators/set.kt");
                    doTestAgainstJava(fileName);
                }
            }
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/staticFun")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class StaticFun extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInStaticFun() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/staticFun"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("classWithNestedEnum.kt")
        public void testClassWithNestedEnum() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/staticFun/classWithNestedEnum.kt");
            doTestAgainstJava(fileName);
        }
    }

    @TestMetadata("compiler/testData/codegen/boxAgainstJava/visibility")
    @TestDataPath("$PROJECT_ROOT")
    @InnerTestClasses({
            Visibility.Package.class,
            Visibility.ProtectedAndPackage.class,
            Visibility.ProtectedStatic.class,
    })
    @RunWith(JUnit3RunnerWithInners.class)
    public static class Visibility extends AbstractBlackBoxCodegenTest {
        public void testAllFilesPresentInVisibility() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/visibility"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/visibility/package")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Package extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInPackage() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/visibility/package"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("kt2781.kt")
            public void testKt2781() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/package/kt2781.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("packageClass.kt")
            public void testPackageClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/package/packageClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("packageFun.kt")
            public void testPackageFun() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/package/packageFun.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("packageProperty.kt")
            public void testPackageProperty() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/package/packageProperty.kt");
                doTestAgainstJava(fileName);
            }
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedAndPackage")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class ProtectedAndPackage extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInProtectedAndPackage() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/visibility/protectedAndPackage"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("overrideProtectedFunInPackage.kt")
            public void testOverrideProtectedFunInPackage() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedAndPackage/overrideProtectedFunInPackage.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("protectedFunInPackage.kt")
            public void testProtectedFunInPackage() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedAndPackage/protectedFunInPackage.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("protectedPropertyInPackage.kt")
            public void testProtectedPropertyInPackage() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedAndPackage/protectedPropertyInPackage.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("protectedStaticClass.kt")
            public void testProtectedStaticClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedAndPackage/protectedStaticClass.kt");
                doTestAgainstJava(fileName);
            }
        }

        @TestMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class ProtectedStatic extends AbstractBlackBoxCodegenTest {
            public void testAllFilesPresentInProtectedStatic() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("funCallInConstructor.kt")
            public void testFunCallInConstructor() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funCallInConstructor.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funClassObject.kt")
            public void testFunClassObject() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funClassObject.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funGenericClass.kt")
            public void testFunGenericClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funGenericClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funNestedStaticClass.kt")
            public void testFunNestedStaticClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funNestedStaticClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funNestedStaticClass2.kt")
            public void testFunNestedStaticClass2() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funNestedStaticClass2.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funNestedStaticGenericClass.kt")
            public void testFunNestedStaticGenericClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funNestedStaticGenericClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funNotDirectSuperClass.kt")
            public void testFunNotDirectSuperClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funNotDirectSuperClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("funObject.kt")
            public void testFunObject() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/funObject.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("simpleClass.kt")
            public void testSimpleClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/simpleClass.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("simpleClass2.kt")
            public void testSimpleClass2() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/simpleClass2.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("simpleFun.kt")
            public void testSimpleFun() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/simpleFun.kt");
                doTestAgainstJava(fileName);
            }

            @TestMetadata("simpleProperty.kt")
            public void testSimpleProperty() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("compiler/testData/codegen/boxAgainstJava/visibility/protectedStatic/simpleProperty.kt");
                doTestAgainstJava(fileName);
            }
        }
    }
}
